=================================
Libreoffice utilities for Tendril
=================================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-libreoffice.svg
        :target: https://travis-ci.org/chintal/tendril-utils-libreoffice

.. image:: https://img.shields.io/pypi/v/tendril-utils-libreoffice.svg
        :target: https://pypi.python.org/pypi/tendril-utils-libreoffice

* License: AGPLv3
* Documentation: http://tendril-utils-libreoffice.readthedocs.org


Libreoffice utilities for Tendril
